==> verttice_ui-0.0.150.tar.gz: lib/src/widgets/drawing/save_paint.dart <==
// 🎯 Dart imports:
import 'dart:typed_data';

// 🐦 Flutter imports:
import 'package:flutter/material.dart';

// 📦 Package imports:
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_models/verttice_models.dart';

// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

class SavePaint extends StatefulWidget {
  final Function(FileModel data) imageDataCallback;
  final String path;
  final Uint8List image;
  final Future<List<FileModel>> Function({
    required BuildContext context,
    required List<UploadFileDataModel> files,
  })? altUploadFilesFun;

  const SavePaint({
    Key? key,
    required this.image,
    required this.imageDataCallback,
    required this.path,
    this.altUploadFilesFun,
  }) : super(key: key);

  @override
  State<SavePaint> createState() => _SavePaintState();
}

class _SavePaintState extends State<SavePaint> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: ThemedAppBar(
        navigateBackButton: true,
        actions: [
          SaveDataHandler(
            future: () async {
              final String fileID = IDs.l16();
              final files = [
                UploadFileDataModel(
                  fileID: fileID,
                  file: widget.image,
                  mimeType: "image/png",
                  path: "${widget.path}/$fileID",
                  name: fileID,
                  size: widget.image.length,
                ),
              ];
              late List<FileModel> response;
              if (widget.altUploadFilesFun != null) {
                response = await widget.altUploadFilesFun!(
                  context: context,
                  files: files,
                );
              } else {
                response = await VertticeUIConfig.instance.uploadFiles(
                  context: context,
                  files: files,
                );
              }
              if (response.isNotEmpty) {
                widget.imageDataCallback(response.first);
              }
            },
            navigateBackOnSaved: true,
          ),
        ],
      ),
      body: Image.memory(widget.image),
    );
  }
}

==> verttice_ui-0.0.153.tar.gz: lib/src/widgets/drawing/save_paint.dart <==
// 🎯 Dart imports:
import 'dart:typed_data';

// 🐦 Flutter imports:
import 'package:flutter/material.dart';

// 📦 Package imports:
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_models/verttice_models.dart';

// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

class SavePaint extends StatefulWidget {
  final Function(FileModel data) imageDataCallback;
  final String path;
  final Uint8List image;
  final Future<List<FileModel>> Function({
    required BuildContext context,
    required List<UploadFileDataModel> files,
  })? altUploadFilesFun;

  const SavePaint({
    Key? key,
    required this.image,
    required this.imageDataCallback,
    required this.path,
    this.altUploadFilesFun,
  }) : super(key: key);

  @override
  State<SavePaint> createState() => _SavePaintState();
}

class _SavePaintState extends State<SavePaint> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: ThemedAppBar(
        navigateBackButton: true,
        actions: [
          SaveDataHandler(
            future: () async {
              final String fileID = IDs.l16();
              final files = [
                UploadFileDataModel(
                  fileID: fileID,
                  file: widget.image,
                  mimeType: "image/png",
                  path: "${widget.path}/$fileID",
                  name: fileID,
                  size: widget.image.length,
                ),
              ];
              late List<FileModel> response;
              if (widget.altUploadFilesFun != null) {
                response = await widget.altUploadFilesFun!(
                  context: context,
                  files: files,
                );
              } else {
                response = await VertticeUI.instance.uploadFiles(
                  context: context,
                  files: files,
                );
              }
              if (response.isNotEmpty) {
                widget.imageDataCallback(response.first);
              }
            },
            navigateBackOnSaved: true,
          ),
        ],
      ),
      body: Image.memory(widget.image),
    );
  }
}
